Module blaxel.core.client.models.integration_endpoint
=====================================================

Classes
-------

`IntegrationEndpoint(body: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, ignore_models: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, method: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, models: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, stream_key: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, stream_token: blaxel.core.client.types.Unset | ForwardRef('IntegrationEndpointToken') = <blaxel.core.client.types.Unset object>, token: blaxel.core.client.types.Unset | ForwardRef('IntegrationEndpointToken') = <blaxel.core.client.types.Unset object>)`
:   Integration endpoint
    
    Attributes:
        body (Union[Unset, str]): Integration endpoint body
        ignore_models (Union[Unset, list[Any]]): Integration endpoint ignore models
        method (Union[Unset, str]): Integration endpoint method
        models (Union[Unset, list[Any]]): Integration endpoint models
        stream_key (Union[Unset, str]): Integration endpoint stream key
        stream_token (Union[Unset, IntegrationEndpointToken]): Integration endpoint token
        token (Union[Unset, IntegrationEndpointToken]): Integration endpoint token
    
    Method generated by attrs for class IntegrationEndpoint.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `body`
    :

    `ignore_models`
    :

    `method`
    :

    `models`
    :

    `stream_key`
    :

    `stream_token`
    :

    `token`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :